#!/bin/bash

ugmp_mpfr="gmp_mpfr"
vgmp="6.2.1"
vmpfr="4.1.0"

sgmp="gmp-$vgmp"
smpfr="mpfr-$vmpfr"

cc=$(gcc -v 2>&1 | grep -o -E "i686|x86_64" -m 1)

if [ "$cc" == "i686" ]; then 
	arch="x32"
elif [ "$cc" == "x86_64" ]; then 
	arch="x64"
fi

libs="/c/libs"
src="$libs/src/${arch}"

out_x="$libs/out/$ugmp_mpfr"
out="$out_x/${arch}"

function make_build_enter {

	set -o xtrace

	cd "$out_x"
	rm -rf "${arch}"
	mkdir "${arch}"

	set +o xtrace
}

function make_build_gmp {

	set +o xtrace

	cc="gcc -static-libgcc"

	set -o xtrace

	cd "$src/$sgmp"
	./configure CC="$cc" --enable-shared --disable-static --prefix="$out" \
		&& make clean > /dev/null \
		&& make > build.log \
		&& make check \
		&& make install

	set +o xtrace
}

function make_build_mpfr {

	set -o xtrace

	cd "$src/$smpfr"
	./configure --enable-shared --disable-static --enable-thread-safe --prefix="$out" --with-gmp="$out" \
		&& make clean > /dev/null \
		&& make > build.log \
		&& {
			set +o xtrace

			cmd=$(grep -o 'gcc -shared.*' build.log)
			cmd+=" -static-libgcc"
			cmd+=" -Wl,-Bstatic -lpthread"

			set -o xtrace

			(cd src && $cmd)
		} \
		&& make check \
		&& make install

	set +o xtrace
}

make_build_enter
make_build_gmp
make_build_mpfr
